# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2025-06-23

### Added

- Add GitHub Actions for build, test and publish to PyPI and TestPyPI
- Fix typos in README

## [0.1.0] - 2025-06-22

### Added

- Initial release

[0.1.1]: https://github.com/ivarurdalen/coinalyze/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/ivarurdalen/coinalyze/releases/tag/v0.1.0
